summaryrefslogtreecommitdiffstats
path: root/routers/api/v1/swagger
diff options
context:
space:
mode:
author6543 <6543@obermui.de>2020-12-18 03:33:32 +0000
committerGitHub <noreply@github.com>2020-12-18 11:33:32 +0800
commite483220ea3c54137cec543842261f99c4696129a (patch)
tree2f81f173315b8ebe92403290977c09bfc32bf754 /routers/api/v1/swagger
parent27edc1aa19afb043a497a7dc628afa420cb1de55 (diff)
downloadgitea-e483220ea3c54137cec543842261f99c4696129a.tar.gz
gitea-e483220ea3c54137cec543842261f99c4696129a.zip
[Refactor] CombinedStatus and CommitStatus related functions & structs (#14026)
* RM unused struct * rename (*CommitStatus) loadRepo() -> loadAttributes() * move ToCommitStatus into its own file * use CommitStatusState instead of StatusState * move CombinedStatus convertion into convert package * let models.GetLatestCommitStatus use repoID direct and accept ListOptions * update swagger docs * fix tests * Fix swagger docs * rm page * fix swagger docs!!! * return json null * always return json * rename api.Status to api.CommitStatus * fix swagger docs * sec swagger fix
Diffstat (limited to 'routers/api/v1/swagger')
-rw-r--r--routers/api/v1/swagger/repo.go21
1 files changed, 14 insertions, 7 deletions
diff --git a/routers/api/v1/swagger/repo.go b/routers/api/v1/swagger/repo.go
index bce9e45c37..d539bcb9fe 100644
--- a/routers/api/v1/swagger/repo.go
+++ b/routers/api/v1/swagger/repo.go
@@ -169,18 +169,18 @@ type swaggerResponsePullReviewCommentList struct {
Body []api.PullReviewComment `json:"body"`
}
// Status
// swagger:response Status
type swaggerResponseStatus struct {
// in:body
- Body api.Status `json:"body"`
+ Body api.CommitStatus `json:"body"`
}
-// StatusList
-// swagger:response StatusList
-type swaggerResponseStatusList struct {
+// CommitStatusList
+// swagger:response CommitStatusList
+type swaggerResponseCommitStatusList struct {
// in:body
- Body []api.Status `json:"body"`
+ Body []api.CommitStatus `json:"body"`
}
// WatchInfo
@@ -309,3 +309,10 @@ type swaggerLanguageStatistics struct {
// in: body
Body map[string]int64 `json:"body"`
}
+
+// CombinedStatus
+// swagger:response CombinedStatus
+type swaggerCombinedStatus struct {
+ // in: body
+ Body api.CombinedStatus `json:"body"`
+}
@@ -169,18 +169,18 @@ type swaggerResponsePullReviewCommentList struct {
Body []api.PullReviewComment `json:"body"`
}
-// Status
-// swagger:response Status
+// CommitStatus
+// swagger:response CommitStatus
type swaggerResponseStatus struct {
// in:body